@@ -3,7 +3,7 @@ package POE::Wheel::SocketFactory;
 use strict;
 
 use vars qw($VERSION @ISA);
-$VERSION = '1.353'; # NOTE - Should be #.### (three decimal places)
+$VERSION = '1.354'; # NOTE - Should be #.### (three decimal places)
 
 use Carp qw( carp croak );
 use Symbol qw( gensym );
@@ -497,7 +497,7 @@ sub new {
   my $domain = delete $params{SocketDomain};
   if (defined $domain) {
     # [rt.cpan.org 76314] Untaint the domain.
-    ($domain) = ($domain =~ /\A(.*)\z/);
+    ($domain) = ($domain =~ /\A(.*)\z/s);
   }
   else {
     $domain = AF_INET;
